@@ -324,6 +324,9 @@ Sample declaration and usage:
   );
   ...
   
+  # Clear and set contents of list
+  print MyClass->bar([ 'Spume', 'Frost' ] );  
+  
   # Set values by position
   MyClass->bar(0 => 'Foozle', 1 => 'Bang!');
   
@@ -339,7 +342,7 @@ Sample declaration and usage:
 There are also calling conventions for slice and splice operations:
 
   # Retrieve slice of values by position
-  print join(', ', MyClass->bar( [0, 2] ) );
+  print join(', ', MyClass->bar( undef, [0, 2] ) );
   
   # Insert an item at position in the array
   MyClass->bar([3], 'Potatoes' );  
@@ -349,9 +352,6 @@ There are also calling conventions for slice and splice operations:
   
   # Set a new value at position 2, and return the old value 
   print MyClass->bar([2, 1], 'Froth' );
-  
-  # Use of undef allows you to clear and set contents of list
-  print MyClass->bar([undef, undef], [ 'Spume', 'Frost' ] );  
 
 =cut
 
@@ -376,9 +376,11 @@ sub array {
 	  if ( $method->{auto_init} and 
 			! defined $method->{global_data} ) {
 	    $method->{global_data} = [];
-	  } else {
-	    $method->{global_data};
 	  }
+	  wantarray ? @{ $method->{global_data} } : $method->{global_data}
+	} elsif ( scalar(@_) == 1 and ref $_[0] eq 'ARRAY' ) {
+	  $method->{global_data} = [ @{ $_[0] } ];
+	  wantarray ? @{ $method->{global_data} } : $method->{global_data}
 	} else {
 	  $method->{global_data} ||= [];
 	  Class::MakeMethods::Composite::__array_ops( 
@@ -406,15 +408,23 @@ The global value will be a reference to a hash (or undef).
 
 =item *
 
-If called without any arguments, returns the current hash-ref value (or undef).
+If called without any arguments, returns the contents of the hash in list context, or a hash reference in scalar context (or undef).
 
 =item *
 
-If called with one argument, uses that argument as an index to retrieve from the referenced hash, and returns that value (or undef). If the single argument is an array ref, then a slice of the referenced hash is returned.
+If called with one non-ref argument, uses that argument as an index to retrieve from the referenced hash, and returns that value (or undef).
 
 =item *
 
-If called with a list of key-value pairs, stores the value under the given key in the referenced hash. If the global value was previously undefined, a new hash is autovivified. The current value under each key will be overwritten, and later arguments with the same key will override earlier ones. Returns the current hash-ref value.
+If called with one array-ref argument, uses the contents of that array to retrieve a slice of the referenced hash.
+
+=item *
+
+If called with one hash-ref argument, sets the contents of the referenced hash to match that provided.
+
+=item *
+
+If called with a list of key-value pairs, stores the value under the given key in the referenced hash. If the global value was previously undefined, a new hash is autovivified. The current value under each key will be overwritten, and later arguments with the same key will override earlier ones. Returns the contents of the hash in list context, or a hash reference in scalar context.
 
 =back
 
@@ -465,13 +475,16 @@ sub hash {
 	if ( scalar(@$args) == 0 ) {
 	  if ( $method->{auto_init} and ! defined $method->{global_data} ) {
 	    $method->{global_data} = {};
-	  } else {
-	    $method->{global_data};
 	  }
+	  wantarray ? %{ $method->{global_data} } : $method->{global_data};
 	} elsif ( scalar(@$args) == 1 ) {
-	  my $index = shift;
-	  ref($index) ? @{$method->{global_data}}{ @$index } 
-		      :   $method->{global_data}->{ $index };
+	  if ( ref($_[0]) eq 'HASH' ) {
+	    %{$method->{global_data}} = %{$_[0]};
+	  } elsif ( ref($_[0]) eq 'ARRAY' ) {
+	    return @{$method->{global_data}}{ @{$_[0]} }
+	  } else {
+	    return $method->{global_data}->{ $_[0] }
+	  }
 	} elsif ( scalar(@$args) % 2 ) {
 	  croak "Odd number of items in assigment to $method->{name}";
 	} else {
@@ -479,7 +492,7 @@ sub hash {
 	    my $key = shift @$args;
 	    $method->{global_data}->{ $key} = shift @$args;
 	  }
-	  $method->{global_data};
+	  wantarray ? %{ $method->{global_data} } : $method->{global_data};
 	}
       },
   ],
